// ========================================
// Thompson submachine gun
// -----------------------------------------
// Made for Persistence of vision 3.6
//==========================================  
// Copyright 2007 Gilles Tran http://www.oyonale.com
// -----------------------------------------
// This work is licensed under the Creative Commons Attribution License. 
// To view a copy of this license, visit http://creativecommons.org/licenses/by/3.0/ 
// or send a letter to Creative Commons, 559 Nathan Abbott Way, Stanford, California 94305, USA.
// You are free:
// - to copy, distribute, display, and perform the work
// - to make derivative works
// - to make commercial use of the work
// Under the following conditions:
// - Attribution. You must give the original author credit.
// - For any reuse or distribution, you must make clear to others the license terms of this work.
// - Any of these conditions can be waived if you get permission from the copyright holder.
// Your fair use and other rights are in no way affected by the above. 
//========================================== 
// Render with +W800 +H600
// no antialiasing needed if the focal blur is turned on
#include "colors.inc"

global_settings {
    radiosity {
        pretrace_start 0.08           // start pretrace at this size
        pretrace_end   0.04           // end pretrace at this size
        count 100                      // higher -> higher quality (1..1600) [35]
        nearest_count 5               // higher -> higher quality (1..10) [5]
        error_bound 0.5               // higher -> smoother, less accurate [1.8]
        recursion_limit 2             // how much interreflections are calculated (1..5+) [3]
        low_error_factor .5           // reduce error_bound during last pretrace step
        gray_threshold 0.0            // increase for weakening colors (0..1) [0]
        minimum_reuse 0.015           // reuse of old radiosity samples [0.015]
        brightness 1                  // brightness of radiosity effects (0..1) [1]
        
        adc_bailout 0.01/2
        normal on                   // take surface normals into account [off]
    }
}


camera {
        location y*40-z*60
        direction z*1.9
        up y
        right -x*image_width/image_height
        look_at y*0
        aperture 3           // [0...N] larger is narrower depth of field (blurrier)
        blur_samples 100        // number of rays per pixel for sampling
        focal_point <0,0,0>    // point that is in focus <X,Y,Z>
        confidence 0.95           // [0...<1] when to move on while sampling (smaller is less accurate)
        variance 1/200            // [0...1] how precise to calculate (smaller is more accurate)


        }
 
light_source {
    <300,150,0>
    color rgb <0.9,1,1>*3
    area_light 100*z,100*y, 10,10 adaptive 1 jitter orient
    fade_distance 120
    fade_power 2

}
 
#declare T_Metal=texture{
    pigment{
        bozo
        scale 1/40
        turbulence 1
        lambda 4
        scale <1,3,1>
        color_map{
            [0.5 rgb <9,11,17>*3/255]
            [1 rgb <9,11,17>*10/255]
        }
    }
    finish{ambient 0 diffuse 0.6 metallic brilliance 3 roughness 1/30 specular 1 reflection {0.23,0.23}}
}
#declare T_Wood =texture{
    pigment{
        wood
        turbulence 0.2
        lambda 3
        scale 10
        rotate y*30
        rotate x*20
        color_map{
            [0 rgb <127, 67, 40>/255]
            [1 rgb <43, 22, 13>/255]
        }
    }
    finish{ambient 0 diffuse 1 specular 0.6 roughness 1/50 reflection {0,0.16}} 
}


#include "thompson_pov.inc"
 
object{Thompson
    rotate y*180
    rotate z*90.705  
    rotate y*60
    translate y*1.282+x*4
}

box{<-400,-1,-400>,<400,300,400> texture{pigment{White} finish{ambient 0 diffuse 1}}}
plane{y,0
    texture{
        pigment{image_map{jpeg "concrete.jpg"}}
        normal{bump_map{jpeg "concrete.jpg" bump_size 2}}
        finish{ambient 0 diffuse 1}
        scale 100
        rotate x*90
    }
}
